==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/SendSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.SendSignal;
import io.ciera.tool.sql.ooaofooa.activity.SendSignalSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class SendSignalSetImpl extends InstanceSet<SendSignalSet,SendSignal> implements SendSignalSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setName( m_Name );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( SendSignal sendsignal : this ) actionnodeset.add( sendsignal.R1107_is_a_ActionNode() );
        return actionnodeset;
    }


    @Override
    public SendSignal nullElement() {
        return SendSignalImpl.EMPTY_SENDSIGNAL;
    }

    @Override
    public SendSignalSet emptySet() {
      return new SendSignalSetImpl();
    }

    @Override
    public SendSignalSet value() {
        return this;
    }

    @Override
    public List<SendSignal> elements() {
        SendSignal[] elements = toArray(new SendSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/SendSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.SendSignal;
import io.ciera.tool.sql.ooaofooa.activity.SendSignalSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SendSignalSetImpl extends InstanceSet<SendSignalSet,SendSignal> implements SendSignalSet {

    public SendSignalSetImpl() {
    }

    public SendSignalSetImpl(Comparator<? super SendSignal> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( SendSignal sendsignal : this ) sendsignal.setName( m_Name );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( SendSignal sendsignal : this ) actionnodeset.add( sendsignal.R1107_is_a_ActionNode() );
        return actionnodeset;
    }


    @Override
    public SendSignal nullElement() {
        return SendSignalImpl.EMPTY_SENDSIGNAL;
    }

    @Override
    public SendSignalSet emptySet() {
      return new SendSignalSetImpl();
    }

    @Override
    public SendSignalSet emptySet(Comparator<? super SendSignal> comp) {
      return new SendSignalSetImpl(comp);
    }

    @Override
    public SendSignalSet value() {
        return this;
    }

    @Override
    public List<SendSignal> elements() {
        SendSignal[] elements = toArray(new SendSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
